#
# spec file for package ip2unix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ip2unix
Version:        2.2.1
Release:        2.4
Summary:        Turn IP sockets into Unix domain sockets
License:        LGPL-3.0-only
URL:            https://github.com/nixcloud/ip2unix/
Source0:        https://github.com/nixcloud/ip2unix/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         https://patch-diff.githubusercontent.com/raw/nixcloud/ip2unix/pull/35.patch#/ip2unix-2.2.1-fix_out_of_range_string_view_access.patch
BuildRequires:  asciidoc
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.47.0
BuildRequires:  python3
BuildRequires:  python3-pytest
BuildRequires:  pkgconfig(yaml-cpp) >= 0.5.0
# systemd-socket-activate is used in tests
BuildRequires:  pkgconfig(systemd)

%description
Executes a program and converts IP to Unix domain sockets at runtime based on a
list of rules, either given via short command line options or via a file with a
list of rules. The first matching rule causes ip2unix to replace the current IP
socket with a Unix domain socket based on the options given. For example if a
socketPath is specified, the Unix domain socket will bind or listen to the given
path.

%prep
%autosetup -p1

%build
# Building with LTO enabled causes crashes. https://github.com/nixcloud/ip2unix/issues/33
%define _lto_cflags %{nil}
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%files
%{_bindir}/%{name}
%{_libdir}/lib%{name}.so
%{_mandir}/man1/%{name}.1%{ext_man}

%changelog
* Sun Apr 14 2024 Adam Mizerski <adam@mizerski.pl>
- added patch ip2unix-2.2.1-fix_out_of_range_string_view_access.patch
* Mon Aug 28 2023 Adam Mizerski <adam@mizerski.pl>
- opt out from lto using _lto_clfags macro
* Mon Aug 21 2023 Adam Mizerski <adam@mizerski.pl>
- update to 2.2.1
  - Fixed
  - Missing serialisation for from-unix and from-abstract.
  - Changed
  - Improve wording/grammar in README and manpage.
- update to 2.2.0
  - Fixed
  - Missing header files for newer GCC versions, thanks to @vamega (#32).
  - Use-after-free of blackhole working directory path.
  - A few compiler warnings on unnecessary allocation of string literals.
  - Added
  - Deprecation warnings if rules are specified in YAML format.
  - Unlink socket file before bind if SO_REUSEADDR is used.
  - Support for Linux abstract sockets.
  - Support for matching an existing Unix domain socket or abstract socket.
  - stream/datagram aliases for tcp/udp socket types.
  - Flag to prevent unlinking of socket files when closing sockets.
  - Changed
  - Rule files (-f) are now just a list of newline-separated rule (-r)
  - arguments instead of YAML files.
  - Improve and overhaul README and man page.
  - Split build instructions into separate file.
  - Include URL to README in usage if manpage is not being built.
  - Turn into a Nix Flake.
  - Improve serializer to be more robust in end-of-stream conditions.
  - Bump requirements to require at least GCC version 9.
  - Removed
  - Badges (eg. LGTM and build status) in README and Hydra.
  - No longer prefer C library path over RTLD_NEXT.
- Removed patches gcc-12.patch, gcc-13.patch - resolved upstream.
* Tue Mar 28 2023 Adam Mizerski <adam@mizerski.pl>
- added patch gcc-13.patch
* Tue Jan 24 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildREquire pkgconfig(systemd) instead of systemd: allow OBS
  to shortcut through the mini flavor.
* Tue May 24 2022 Adam Mizerski <adam@mizerski.pl>
- added patch gcc-12.patch
* Sat Jul 10 2021 Adam Mizerski <adam@mizerski.pl>
- update to 2.1.4
  - Ordering between systemd socket file descriptor names and rules.
  - Usage of C library path as discovered by Meson.
* Mon Jun  1 2020 Adam Mizerski <adam@mizerski.pl>
- update to 2.1.3
* Wed May 27 2020 Adam Mizerski <adam@mizerski.pl>
- new package; version 2.1.2
